==> jc-1.4.0.tar.gz: java/util/Collections__24UnmodifiableSortedSet.h <==
// class java.util.Collections$UnmodifiableSortedSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2126b28aee607999 java_util_Collections__24UnmodifiableCollection
// @dep_class aec2ea3fc69f0e47 java_util_Collections__24UnmodifiableSet
// @dep_class ca93122cb3ca53dd java_util_Collections__24UnmodifiableSortedSet

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableSet

#include "java/util/Collections__24UnmodifiableSet.h"

#ifndef _JC_java_util_Collections__24UnmodifiableSortedSet_H_
#define _JC_java_util_Collections__24UnmodifiableSortedSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Comparator$object;
struct _jc_java_util_SortedSet$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$sub_refs	_jc_java_util_Collections__24UnmodifiableSortedSet$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableSortedSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$refs	_jc_java_util_Collections__24UnmodifiableSortedSet$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$nonrefs	_jc_java_util_Collections__24UnmodifiableSortedSet$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$object	_jc_java_util_Collections__24UnmodifiableSortedSet$object;

typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$fields_struct	_jc_java_util_Collections__24UnmodifiableSortedSet$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedSet$vmethods	_jc_java_util_Collections__24UnmodifiableSortedSet$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedSet$vtable	_jc_java_util_Collections__24UnmodifiableSortedSet$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedSet$vtype	_jc_java_util_Collections__24UnmodifiableSortedSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableSortedSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableSortedSet$fields_struct _jc_java_util_Collections__24UnmodifiableSortedSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableSortedSet$method$_init$5032ef36ef0249d2(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$comparator$685c966d9d487177(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$first$a2209d53e8798ae9(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *);
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$headSet$72d702a39ed180e1(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$last$8d4ca469e4351f26(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *);
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$subSet$61b81a78b18145f9(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$tailSet$fb8c95af95cf5eae(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$comparator$685c966d9d487177;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$first$a2209d53e8798ae9;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$headSet$72d702a39ed180e1;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$last$8d4ca469e4351f26;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$subSet$61b81a78b18145f9;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$tailSet$fb8c95af95cf5eae;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableSortedSet$vmethods {
	struct _jc_object	*(*comparator$685c966d9d487177)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *);
	struct _jc_java_lang_Object$object	*(*first$a2209d53e8798ae9)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *);
	struct _jc_object	*(*headSet$72d702a39ed180e1)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*last$8d4ca469e4351f26)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *);
	struct _jc_object	*(*subSet$61b81a78b18145f9)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*tailSet$fb8c95af95cf5eae)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableSortedSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableCollection$vmethods	java_util_Collections__24UnmodifiableCollection;
	_jc_java_util_Collections__24UnmodifiableSet$vmethods	java_util_Collections__24UnmodifiableSet;
	_jc_java_util_Collections__24UnmodifiableSortedSet$vmethods	java_util_Collections__24UnmodifiableSortedSet;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableSortedSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableSortedSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSortedSet$sub_refs {
	struct _jc_object	*ss;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSortedSet$refs {
    _jc_java_util_Collections__24UnmodifiableSortedSet$sub_refs	java_util_Collections__24UnmodifiableSortedSet;
    _jc_java_util_Collections__24UnmodifiableSet$sub_refs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_refs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSortedSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSortedSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_nonrefs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableSortedSet$sub_nonrefs	java_util_Collections__24UnmodifiableSortedSet;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableSortedSet$object {
	_jc_java_util_Collections__24UnmodifiableSortedSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableSortedSet$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableSortedSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableSortedSet$vtype _jc_java_util_Collections__24UnmodifiableSortedSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableSortedSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableSortedSet$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableSortedSet_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24UnmodifiableSortedSet.h <==
// class java.util.Collections$UnmodifiableSortedSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2126b28aee607999 java_util_Collections__24UnmodifiableCollection
// @dep_class aec2ea3fc69f0e47 java_util_Collections__24UnmodifiableSet
// @dep_class ca93122cb3ca53dd java_util_Collections__24UnmodifiableSortedSet

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableSet

#include "java/util/Collections__24UnmodifiableSet.h"

#ifndef _JC_java_util_Collections__24UnmodifiableSortedSet_H_
#define _JC_java_util_Collections__24UnmodifiableSortedSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Comparator$object;
struct _jc_java_util_SortedSet$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$sub_refs	_jc_java_util_Collections__24UnmodifiableSortedSet$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableSortedSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$refs	_jc_java_util_Collections__24UnmodifiableSortedSet$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$nonrefs	_jc_java_util_Collections__24UnmodifiableSortedSet$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$object	_jc_java_util_Collections__24UnmodifiableSortedSet$object;

typedef struct _jc_java_util_Collections__24UnmodifiableSortedSet$fields_struct	_jc_java_util_Collections__24UnmodifiableSortedSet$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedSet$vmethods	_jc_java_util_Collections__24UnmodifiableSortedSet$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedSet$vtable	_jc_java_util_Collections__24UnmodifiableSortedSet$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableSortedSet$vtype	_jc_java_util_Collections__24UnmodifiableSortedSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableSortedSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableSortedSet$fields_struct _jc_java_util_Collections__24UnmodifiableSortedSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableSortedSet$method$_init$5032ef36ef0249d2(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$comparator$685c966d9d487177(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$first$a2209d53e8798ae9(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$headSet$72d702a39ed180e1(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$last$8d4ca469e4351f26(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$subSet$61b81a78b18145f9(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableSortedSet$method$tailSet$fb8c95af95cf5eae(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$comparator$685c966d9d487177;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$first$a2209d53e8798ae9;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$headSet$72d702a39ed180e1;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$last$8d4ca469e4351f26;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$subSet$61b81a78b18145f9;
extern _jc_method _jc_java_util_Collections__24UnmodifiableSortedSet$method_info$tailSet$fb8c95af95cf5eae;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableSortedSet$vmethods {
	struct _jc_object	*(*comparator$685c966d9d487177)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*first$a2209d53e8798ae9)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*headSet$72d702a39ed180e1)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*last$8d4ca469e4351f26)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*subSet$61b81a78b18145f9)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*tailSet$fb8c95af95cf5eae)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableSortedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableSortedSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableCollection$vmethods	java_util_Collections__24UnmodifiableCollection;
	_jc_java_util_Collections__24UnmodifiableSet$vmethods	java_util_Collections__24UnmodifiableSet;
	_jc_java_util_Collections__24UnmodifiableSortedSet$vmethods	java_util_Collections__24UnmodifiableSortedSet;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableSortedSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableSortedSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSortedSet$sub_refs {
	struct _jc_object	*ss;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSortedSet$refs {
    _jc_java_util_Collections__24UnmodifiableSortedSet$sub_refs	java_util_Collections__24UnmodifiableSortedSet;
    _jc_java_util_Collections__24UnmodifiableSet$sub_refs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_refs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableSortedSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableSortedSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_nonrefs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableSortedSet$sub_nonrefs	java_util_Collections__24UnmodifiableSortedSet;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableSortedSet$object {
	_jc_java_util_Collections__24UnmodifiableSortedSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableSortedSet$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableSortedSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableSortedSet$vtype _jc_java_util_Collections__24UnmodifiableSortedSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableSortedSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableSortedSet$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableSortedSet_H_ */
